@@ -76,6 +76,26 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 
       switch (tag)
 	{
+#if GOBJECT_INTROSPECTION_VERSION >= 0x000900
+	case GI_TYPE_TAG_LONG:
+	  arg->v_long = *(glong *) args[i];
+	  break;
+	case GI_TYPE_TAG_ULONG:
+	  arg->v_ulong = *(gulong *) args[i];
+	  break;
+	case GI_TYPE_TAG_INT:
+	  arg->v_int = *(gint *) args[i];
+	  break;
+	case GI_TYPE_TAG_SSIZE:
+	  arg->v_ssize = *(gssize *) args[i];
+	  break;
+	case GI_TYPE_TAG_SIZE:
+	  arg->v_size = *(gsize *) args[i];
+	  break;
+	case GI_TYPE_TAG_UINT:
+	  arg->v_uint = *(guint *) args[i];
+	  break;
+#endif
 	case GI_TYPE_TAG_BOOLEAN:
 	  arg->v_boolean = *(gboolean *) args[i];
 	  break;
@@ -175,7 +195,26 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 			 &return_arg, 0);
   switch (return_tag)
     {
-
+#if GOBJECT_INTROSPECTION_VERSION >= 0x000900
+    case GI_TYPE_TAG_LONG:
+      *(glong *) result = return_arg.v_long;
+      break;
+    case GI_TYPE_TAG_ULONG:
+      *(gulong *) result = return_arg.v_ulong;
+      break;
+    case GI_TYPE_TAG_INT:
+      *(gint *) result = return_arg.v_int;
+      break;
+    case GI_TYPE_TAG_SSIZE:
+      *(gssize *) result = return_arg.v_ssize;
+      break;
+    case GI_TYPE_TAG_SIZE:
+      *(gsize *) result = return_arg.v_size;
+      break;
+    case GI_TYPE_TAG_UINT:
+      *(guint *) result = return_arg.v_uint;
+      break;
+#endif
     case GI_TYPE_TAG_BOOLEAN:
       *(gboolean *) result = return_arg.v_boolean;
       break;
