@@ -286,6 +286,11 @@ seed_struct_set_property (JSContextRef context,
   seed_gi_make_argument (context, value, field_type, &field_value, exception);
   ret = g_field_info_set_field (field, priv->pointer, &field_value);
 
+  if (!ret) 
+    g_warning("Setting property failed on struct of type: %s  "
+			"with name %s \n",
+			g_base_info_get_name (priv->info), cproperty_name);
+  
   g_base_info_unref ((GIBaseInfo *) field_type);
   g_base_info_unref ((GIBaseInfo *) field);
 
@@ -311,6 +316,15 @@ seed_struct_get_property (JSContextRef context,
 	     "with name %s \n",
 	     g_base_info_get_name (priv->info), cproperty_name);
 
+  // for a gvalue, it has a special property 'value' (read-only)
+  GType gtype = g_registered_type_info_get_g_type ((GIRegisteredTypeInfo *) priv->info);
+
+  if (g_type_is_a (gtype, G_TYPE_VALUE) && !g_strcmp0 (cproperty_name, "value")) 
+    {
+      return seed_value_from_gvalue ( context, ( GValue *) priv->pointer,  exception);
+ 
+    }
+
   field =
     seed_struct_find_field ((GIStructInfo *) priv->info, cproperty_name);
 
@@ -544,7 +558,7 @@ seed_make_union (JSContextRef ctx, gpointer younion, GIBaseInfo * info)
 
   if (younion == NULL)
     {
-      return JSValueMakeNull (ctx);
+      return (JSObjectRef) JSValueMakeNull (ctx);
     }
 
   seed_struct_privates *priv = g_slice_alloc (sizeof (seed_struct_privates));
@@ -636,7 +650,7 @@ seed_make_struct (JSContextRef ctx, gpointer strukt, GIBaseInfo * info)
 
   if (strukt == NULL)
     {
-      return JSValueMakeNull (ctx);
+      return (JSObjectRef) JSValueMakeNull (ctx);
     }
 
   seed_struct_privates *priv = g_slice_alloc (sizeof (seed_struct_privates));
@@ -684,6 +698,7 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
   gpointer object;
   GIInfoType type = g_base_info_get_type (info);
   JSObjectRef ret;
+  gboolean set_ret;
   gint nparams, i = 0;
   gsize length;
   GIFieldInfo *field = 0;
@@ -696,6 +711,21 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
 
   if (type == GI_INFO_TYPE_STRUCT)
     {
+      GType gtype = g_registered_type_info_get_g_type ((GIRegisteredTypeInfo *) info);
+      if (g_type_is_a (gtype, G_TYPE_VALUE)) 
+        {
+          GValue *gval = g_slice_alloc0 (sizeof (GValue));
+          if (!parameters) 
+            {
+              seed_make_exception (ctx, exception, "ArgumentError",  "Missing Type in GValue constructor");
+              return (JSObjectRef) JSValueMakeNull (ctx);
+            }
+          SEED_NOTE (CONSTRUCTION, "Created a GValue  struct");
+          seed_gvalue_from_seed_value (ctx,   parameters , 0,  gval, exception);
+          ret = seed_make_struct (ctx, (gpointer)gval, info);
+          return ret;
+        }
+
       size = g_struct_info_get_size ((GIStructInfo *) info);
     }
   else
@@ -757,8 +787,13 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
 
       seed_gi_make_argument (ctx, jsprop_value, field_type, &field_value,
 			     exception);
-      g_field_info_set_field (field, object, &field_value);
+      set_ret = g_field_info_set_field (field, object, &field_value);
 
+	  if (!set_ret) 
+		g_warning("Constructor setting property failed on struct of type: %s "
+			"with name %s \n",
+			g_base_info_get_name (info), prop_name);
+  
       g_base_info_unref ((GIBaseInfo *) field_type);
       g_base_info_unref ((GIBaseInfo *) field);
 
